@@ -1,6 +1,6 @@
 package Map::Tube::Plugin::Graph;
 
-$Map::Tube::Plugin::Graph::VERSION = '0.05';
+$Map::Tube::Plugin::Graph::VERSION = '0.06';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Map::Tube::Plugin::Graph - Graph plugin for Map::Tube.
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
@@ -117,13 +117,11 @@ sub as_image {
     $color    = $self->line->color if (defined $self->line->color);
     my $line  = $self->line->name;
     my $tube  = $self->tube->name;
-    $tube = 'Map' unless defined $tube;
-    my $label = sprintf("%s: %s", $tube, $line);
     my $graph = GraphViz2->new(
         edge   => { color    => $color                              },
         node   => { shape    => $self->shape                        },
         global => { directed => $self->directed                     },
-        graph  => { label    => $label, labelloc => $self->labelloc });
+        graph  => { label    => _label($line, $tube), labelloc => $self->labelloc });
 
     my $stations = $self->line->get_stations;
 
@@ -159,6 +157,23 @@ sub as_image {
     return encode_base64($raw_string);
 }
 
+#
+#
+# PRIVATE METHODS
+
+sub _label {
+    my ($line, $tube) = @_;
+
+    $tube = '' unless defined $tube;
+    return sprintf("%s Map: %s Line\nGenerated by Map::Tube::Plugin::Graph v%s\nTimestamp: %s",
+                   $tube, $line, $Map::Tube::Plugin::Graph::VERSION, _timestamp());
+}
+
+sub _timestamp {
+    my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst) = localtime(time);
+    return sprintf("%04d-%02d-%02d %02d:%02d:%02d", $year+1900, $mon+1, $mday, $hour, $min, $sec);
+}
+
 =head2 tube($tube)
 
 Sets the attribute 'tube', an object of package with the role L<Map::Tube>.
